##  Creating Authorization Packages
### Context
Authorization packages simplify the process of assigning multiple permissions to users by grouping them into reusable bundles. You can apply these packages directly to S-user IDs in your company, making it easier to manage access for users with similar roles or responsibilities.
### Procedure
  1. Go to SAP for Me.
  2. In the User Management area, go to Home > Users & Contacts > User Management.
  3. Choose Auth. Packages from the menu.
  4. Choose Create.
  5. On the Create Authorization Package screen, enter a name.
  6. Optional: Super administrators can turn on Write Protection so others can't modify the package.
  7. Select all authorizations to be assigned to the package (for example, all case authorizations).
  8. Choose Save.
